Puppet::Type.type(:ovn_metadata_agent_config).provide(
  :ini_setting,
  :parent => Puppet::Type.type(:openstack_config).provider(:ini_setting)
) do

  def self.file_path
    '/etc/neutron/neutron_ovn_metadata_agent.ini'
  end

end
